==> fans-common-core-1.0.7-sources.jar: com/ptteng/sca/fans/common/client/MessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.Message;
import com.ptteng.fans.common.service.MessageService;

import java.util.List;
import java.util.Map;

public class MessageSCAClient implements MessageService {

    private MessageService messageService;

	public MessageService getMessageService() {
		return messageService;
	}
	
	
	public void setMessageService(MessageService messageService) {
		this.messageService =messageService;
	}
	
	
			   
		@Override
		public Long insert(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.insert(message);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> insertList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.insertList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.update(message);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.updateList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public Message getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByTypeAndUserId(Integer type,Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByTypeAndUserId(type,userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByType(Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByType(type,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByTypeAndUserId(Integer type,Long userId)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByTypeAndUserId(type,userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByType(Integer type)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByType(type);
	
	
	}
	
		
	
		@Override
	public List<Long> getMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getMessageIds(start, limit);
	}

	@Override
	public Integer countMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.countMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   messageService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.messageService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> fans-common-core-1.1.11-sources.jar: com/ptteng/sca/fans/common/client/MessageSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.fans.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.fans.common.model.Message;
import com.ptteng.fans.common.service.MessageService;

import java.util.List;
import java.util.Map;

public class MessageSCAClient implements MessageService {

    private MessageService messageService;

	public MessageService getMessageService() {
		return messageService;
	}
	
	
	public void setMessageService(MessageService messageService) {
		this.messageService =messageService;
	}
	
	
			   
		@Override
		public Long insert(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.insert(message);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> insertList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.insertList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(Message message)throws ServiceException, ServiceDaoException{
		
		return messageService.update(message);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<Message> messageList)throws ServiceException, ServiceDaoException{
		
		return messageService.updateList(messageList);
		          
		
		}	
		  
    	   
		@Override
		public Message getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<Message> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return messageService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByTypeAndUserId(Integer type,Long userId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByTypeAndUserId(type,userId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getMessageIdsByType(Integer type,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return messageService.getMessageIdsByType(type,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByTypeAndUserId(Integer type,Long userId)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByTypeAndUserId(type,userId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countMessageIdsByType(Integer type)throws ServiceException, ServiceDaoException{
		
		return messageService.countMessageIdsByType(type);
	
	
	}
	
		
	
		@Override
	public List<Long> getMessageIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getMessageIds(start, limit);
	}

	@Override
	public Integer countMessageIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.countMessageIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return messageService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   messageService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.messageService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

    @Override
    public Object getMapListByDynamicCondition(Class clz,Map<String, Object> conditions, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return this.messageService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
